import { IconComponent } from '@consta/icons/Icon';
import React from 'react';
import { PropsWithHTMLAttributesAndRef } from '../../utils/types/PropsWithHTMLAttributes';
export declare const progressStepBarPropSize: readonly ["s", "xs", "m"];
export type ProgressStepBarPropSize = typeof progressStepBarPropSize[number];
export declare const progressStepBarPropSizeDefault: "s";
export declare const progressStepBarPropDirection: readonly ["horizontal", "vertical"];
export type ProgressStepBarPropDirection = typeof progressStepBarPropDirection[number];
export declare const progressStepBarPropDirectionDefault: "horizontal";
export declare const progressStepBarPropStatus: readonly ["normal", "success", "warning", "alert"];
export type ProgressStepBarPropStatus = typeof progressStepBarPropStatus[number];
export declare const progressStepBarPropStatusDefault: "normal";
export declare const progressStepBarPointNumbersMap: readonly [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
export type ProgressStepBarPointNumbersMap = typeof progressStepBarPointNumbersMap[number];
export declare const progressStepBarPropPosition: readonly ["center", "start", "end"];
export type ProgressStepBarPropPosition = typeof progressStepBarPropPosition[number];
export declare const progressStepBarPropPositionDefault: ProgressStepBarPropPosition;
export type ProgressStepBarPropGetItemLabel<ITEM> = (item: ITEM) => string | undefined;
export type ProgressStepBarPropGetItemKey<ITEM> = (item: ITEM) => string | number;
export type ProgressStepBarPropGetItemTooltipContent<ITEM> = (item: ITEM) => string | undefined;
export type ProgressStepBarPropGetItemLineStatus<ITEM> = (item: ITEM) => ProgressStepBarPropStatus | undefined;
export type ProgressStepBarPropGetItemPoint<ITEM> = (item: ITEM) => ProgressStepBarPointNumbersMap | IconComponent | undefined;
export type ProgressStepBarPropGetItemProgress<ITEM> = (item: ITEM) => boolean | undefined;
export type ProgressStepBarPropGetItemContent<ITEM> = (item: ITEM) => React.ReactNode | undefined;
export type ProgressStepBarPropGetItemStatus<ITEM> = (item: ITEM) => ProgressStepBarPropStatus | undefined;
export type ProgressStepBarPropGetItemOnClick<ITEM> = (item: ITEM) => React.EventHandler<React.MouseEvent> | undefined;
export type ProgressStepBarItemDefault = {
    label?: string;
    tooltipContent?: string;
    lineStatus?: ProgressStepBarPropStatus;
    point?: ProgressStepBarPointNumbersMap | IconComponent;
    status?: ProgressStepBarPropStatus;
    progress?: boolean;
    content?: React.ReactNode;
    onClick?: React.EventHandler<React.MouseEvent>;
};
export type Line = {
    status: ProgressStepBarPropStatus;
    size: number;
};
export type ProgressStepBarPropOnItemClick<ITEM> = (item: ITEM, props: {
    e: React.MouseEvent;
    index: number;
}) => void;
export type ProgressStepBarProps<ITEM = ProgressStepBarItemDefault> = PropsWithHTMLAttributesAndRef<{
    steps: ITEM[];
    direction?: ProgressStepBarPropDirection;
    size?: ProgressStepBarPropSize;
    activeStepIndex?: number;
    onItemClick?: ProgressStepBarPropOnItemClick<ITEM>;
    getItemLabel?: ProgressStepBarPropGetItemLabel<ITEM>;
    getItemLineStatus?: ProgressStepBarPropGetItemLineStatus<ITEM>;
    getItemTooltipContent?: ProgressStepBarPropGetItemTooltipContent<ITEM>;
    getItemPoint?: ProgressStepBarPropGetItemPoint<ITEM>;
    getItemProgress?: ProgressStepBarPropGetItemProgress<ITEM>;
    getItemContent?: ProgressStepBarPropGetItemContent<ITEM>;
    getItemStatus?: ProgressStepBarPropGetItemStatus<ITEM>;
    getItemOnClick?: ProgressStepBarPropGetItemOnClick<ITEM>;
}, HTMLDivElement> & (ITEM extends {
    label: ProgressStepBarItemDefault['label'];
} ? {} : {
    getItemLabel: ProgressStepBarPropGetItemLabel<ITEM>;
});
export type ProgressStepBarItemProps = {
    content?: React.ReactNode;
    label?: string;
    point?: ProgressStepBarPointNumbersMap | IconComponent;
    progress?: boolean;
    status?: ProgressStepBarPropStatus | 'system';
    tooltipContent?: string;
    tooltipZIndex?: number;
    position?: ProgressStepBarPropPosition;
    direction: ProgressStepBarPropDirection;
    size: ProgressStepBarPropSize;
    onClick?: (e: React.MouseEvent) => void;
    pointRef?: React.RefObject<HTMLButtonElement>;
    className?: string;
};
export declare const cnProgressStepBar: import("@bem-react/classname").ClassNameFormatter;
export declare const defaultGetItemLabel: ProgressStepBarPropGetItemLabel<ProgressStepBarItemDefault>;
export declare const defaultGetItemTooltipContent: ProgressStepBarPropGetItemTooltipContent<ProgressStepBarItemDefault>;
export declare const defaultGetItemPoint: ProgressStepBarPropGetItemPoint<ProgressStepBarItemDefault>;
export declare const defaultGetItemLineStatus: ProgressStepBarPropGetItemLineStatus<ProgressStepBarItemDefault>;
export declare const defaultGetItemProgress: ProgressStepBarPropGetItemProgress<ProgressStepBarItemDefault>;
export declare const defaultGetItemContent: ProgressStepBarPropGetItemContent<ProgressStepBarItemDefault>;
export declare const defaultGetItemStatus: ProgressStepBarPropGetItemStatus<ProgressStepBarItemDefault>;
export declare const defaultGetItemOnClick: ProgressStepBarPropGetItemOnClick<ProgressStepBarItemDefault>;
export type ProgressStepBarComponent = <ITEM = ProgressStepBarItemDefault>(props: ProgressStepBarProps<ITEM>) => React.ReactNode | null;
export type ProgressStepBarItemComponent = (props: PropsWithHTMLAttributesAndRef<ProgressStepBarItemProps, HTMLDivElement>) => React.ReactNode | null;
export declare function withDefaultGetters<ITEM>(props: ProgressStepBarProps<ITEM>): {
    steps: ITEM[];
    direction?: ProgressStepBarPropDirection;
    size?: ProgressStepBarPropSize;
    activeStepIndex?: number;
    onItemClick?: ProgressStepBarPropOnItemClick<ITEM> | undefined;
    getItemLabel?: ProgressStepBarPropGetItemLabel<ITEM> | undefined;
    getItemLineStatus?: ProgressStepBarPropGetItemLineStatus<ITEM> | undefined;
    getItemTooltipContent?: ProgressStepBarPropGetItemTooltipContent<ITEM> | undefined;
    getItemPoint?: ProgressStepBarPropGetItemPoint<ITEM> | undefined;
    getItemProgress?: ProgressStepBarPropGetItemProgress<ITEM> | undefined;
    getItemContent?: ProgressStepBarPropGetItemContent<ITEM> | undefined;
    getItemStatus?: ProgressStepBarPropGetItemStatus<ITEM> | undefined;
    getItemOnClick?: ProgressStepBarPropGetItemOnClick<ITEM> | undefined;
} & Omit<React.HTMLAttributes<HTMLDivElement>, "css" | "size" | "getItemLabel" | "getItemStatus" | "getItemProgress" | "direction" | "onItemClick" | "getItemOnClick" | "getItemContent" | "steps" | "activeStepIndex" | "getItemLineStatus" | "getItemTooltipContent" | "getItemPoint"> & React.RefAttributes<HTMLDivElement> & (ITEM extends {
    label: ProgressStepBarItemDefault["label"];
} ? {} : {
    getItemLabel: ProgressStepBarPropGetItemLabel<ITEM>;
}) & {
    getItemLabel: ProgressStepBarPropGetItemLabel<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemLabel<ITEM>;
    getItemTooltipContent: ProgressStepBarPropGetItemTooltipContent<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemTooltipContent<ITEM>;
    getItemPoint: ProgressStepBarPropGetItemPoint<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemPoint<ITEM>;
    getItemProgress: ProgressStepBarPropGetItemProgress<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemProgress<ITEM>;
    getItemContent: ProgressStepBarPropGetItemContent<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemContent<ITEM>;
    getItemStatus: ProgressStepBarPropGetItemStatus<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemStatus<ITEM>;
    getItemLineStatus: ProgressStepBarPropGetItemLineStatus<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemLineStatus<ITEM>;
    getItemOnClick: ProgressStepBarPropGetItemOnClick<ProgressStepBarItemDefault> | ProgressStepBarPropGetItemOnClick<ITEM>;
};
export declare const getItemPosition: (index: number, length: number) => "center" | "start" | "end";
export declare const getLineSize: (container: React.RefObject<HTMLElement>, activeElement: React.RefObject<HTMLElement>, direction: ProgressStepBarPropDirection) => number;
export declare const calculateLines: (refs: React.RefObject<HTMLElement>[], direction: ProgressStepBarPropDirection) => number[];
export declare const validateVisibleIndex: (length: number, index: number | undefined) => number | undefined;
