import React from 'react';
import { SortByProps, TableColumn, TableRow, ValueOf } from './Table';
export type FilterComponentProps = {
    onConfirm: (value: unknown) => void;
    onCancel: () => void;
    filterValue?: unknown;
} & Record<string, unknown>;
export type Filters<T extends TableRow> = ValueOf<{
    [K in keyof T]: {
        id: string;
        name: string;
        field: K extends string ? K : never;
        filterer(value: any, filterValue?: unknown): boolean;
    } & ({
        component?: never;
    } | {
        component: {
            name: React.FC<FilterComponentProps>;
            props?: Omit<FilterComponentProps, 'onConfirm' | 'filterValue'>;
        };
    });
}>[];
export type onSortBy<T extends TableRow> = (props: SortByProps<T> | null) => void;
export type FieldSelectedValues = string[];
type SelectedFilter = {
    selected: FieldSelectedValues;
    value?: any;
};
export type SelectedFilters = {
    [field: string]: SelectedFilter;
};
type SelectedFiltersList = Array<{
    id: string;
    name: string;
}>;
export declare const getOptionsForFilters: <T extends TableRow>(filters: Filters<T>, field: string) => {
    value: string;
    label: string;
}[];
export declare const getSelectedFiltersInitialState: <T extends TableRow>(filters?: Filters<T>) => SelectedFilters;
export declare const fieldFiltersPresent: <T extends TableRow>(tableFilters: Filters<T>, field: string) => boolean;
export declare const isSelectedFiltersPresent: (selectedFilters: SelectedFilters) => boolean;
export declare const getSelectedFiltersList: <T extends TableRow>({ filters, selectedFilters, columns, }: {
    filters: Filters<T>;
    selectedFilters: SelectedFilters;
    columns: Array<TableColumn<T>>;
}) => SelectedFiltersList;
export declare const filterTableData: <T extends TableRow>({ data, filters, selectedFilters, }: {
    data: T[];
    filters: Filters<T>;
    selectedFilters: SelectedFilters;
}) => T[];
export declare const useSelectedFilters: <T extends TableRow>(filters?: Filters<T>, onFiltersUpdated?: (filters: SelectedFilters) => void) => {
    selectedFilters: SelectedFilters;
    updateSelectedFilters: (field: string, tooltipSelectedFilters: FieldSelectedValues, value?: unknown) => void;
    removeOneSelectedFilter: (availableFilters: Filters<T>, filter: string) => void;
    removeAllSelectedFilters: (availableFilters: Filters<T>) => void;
};
export {};
