import React from 'react';
import { CountedGroup, SelectAllItem } from '../../utils/getGroups';
type IndexForHighlight = number | ((oldIndex: number) => number);
type Group<ITEM, GROUP> = {
    items: ITEM[];
    key: string | number;
    group?: GROUP;
};
type GetItemGroupKey<ITEM> = (item: ITEM) => string | number | undefined;
type GetGroupKey<GROUP> = (item: GROUP) => string | number | undefined;
type SortGroups<ITEM, GROUP> = (a: Group<ITEM, GROUP>, b: Group<ITEM, GROUP>) => number;
type OnChangeProp<ITEM, MULTIPLE extends boolean> = (props: {
    value: (MULTIPLE extends true ? ITEM[] : ITEM) | null;
    e: React.SyntheticEvent;
}) => void;
type ValueProp<ITEM, MULTIPLE extends boolean> = (MULTIPLE extends true ? ITEM[] : ITEM) | null | undefined;
export type OptionForCreate = {
    label: string;
    __optionForCreate: boolean;
};
export type SelectProps<ITEM, GROUP, MULTIPLE extends boolean> = {
    getItemGroupKey?: GetItemGroupKey<ITEM> | undefined;
    getGroupKey?: GetGroupKey<GROUP>;
    sortGroups?: SortGroups<ITEM, GROUP>;
    groups?: GROUP[];
    items: ITEM[];
    dropdownRef: React.MutableRefObject<HTMLDivElement | null>;
    controlRef: React.MutableRefObject<HTMLDivElement | null>;
    disabled?: boolean;
    selectAll?: boolean;
    getItemLabel: (item: ITEM) => string;
    getItemKey: (item: ITEM) => string | number;
    getItemDisabled?: (item: ITEM) => boolean | undefined;
    searchFunction?: (item: ITEM, searchValue: string) => boolean;
    onCreate?: (props: {
        e: React.SyntheticEvent;
        label: string;
    }) => void;
    onFocus?: React.FocusEventHandler<HTMLInputElement>;
    onBlur?: React.FocusEventHandler<HTMLInputElement>;
    multiple: boolean;
    searchValue?: string;
    withoutClearSearch?: boolean;
    onChange: OnChangeProp<ITEM, MULTIPLE>;
    value: ValueProp<ITEM, MULTIPLE>;
};
export type OptionProps<ITEM> = {
    index: number;
    item: ITEM | OptionForCreate | SelectAllItem;
};
export type GetOptionPropsResult = {
    onClick: (e: React.SyntheticEvent) => void;
    onMouseEnter: (e: React.SyntheticEvent) => void;
    active: boolean;
    hovered: boolean;
    key: string | number;
};
export declare const isOptionForCreate: <ITEM, GROUP>(params: OptionForCreate | Group<ITEM, GROUP> | ITEM) => params is OptionForCreate;
export declare const isOptionForSelectAll: <ITEM, GROUP>(params: SelectAllItem | Group<ITEM, GROUP> | ITEM) => params is SelectAllItem;
export declare function useSelect<ITEM, GROUP, MULTIPLE extends boolean>(params: SelectProps<ITEM, GROUP, MULTIPLE>): {
    isOpen: boolean;
    isFocused: boolean;
    highlightedIndex: number;
    visibleItems: (OptionForCreate | CountedGroup<ITEM, GROUP>)[];
    highlightIndex: (indexForHighlight: IndexForHighlight, scrollToHighlighted: boolean) => void;
    getOptionProps: ({ index, item, }: OptionProps<ITEM>) => GetOptionPropsResult;
    handleInputFocus: (e: React.FocusEvent<HTMLInputElement>) => void;
    handleInputBlur: (e: React.FocusEvent<HTMLInputElement>) => void;
    handleToggleDropdown: () => void;
    handleInputClick: () => void;
    inputRef: React.RefObject<HTMLInputElement>;
    getKeyProps: (rest?: import("../useKeysDeprecated/useKeysDeprecated").KeyProps) => import("../useKeysDeprecated/useKeysDeprecated").KeyProps;
    handleInputChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
    searchValue: string;
    clearValue: (e: React.SyntheticEvent) => void;
    getHandleRemoveValue: (item: ITEM) => (e: React.SyntheticEvent) => void;
    notFound: boolean;
    hasItems: boolean;
};
export {};
